@@ -64,7 +64,7 @@ import jc.utils
 
 class info():
     version = '1.1'
-    description = 'airport -I command parser'
+    description = '`airport -I` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     # details = 'enter any other details here'
