@@ -97,7 +97,7 @@ import jc.parsers.universal
 
 class info():
     version = '1.2'
-    description = 'airport -s command parser'
+    description = '`airport -s` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     # details = 'enter any other details here'
