@@ -144,7 +144,7 @@ import jc.parsers.universal
 
 class info():
     version = '1.4'
-    description = 'crontab command and file parser'
+    description = '`crontab` command and file parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     # details = 'enter any other details here'
