@@ -1,5 +1,9 @@
 """jc - JSON CLI output utility `dig` command output parser
 
+The `when_epoch` calculated timestamp field is naive (i.e. based on the local time of the system the parser is run on)
+
+The `when_epoch_utc` calculated timestamp field is timezone-aware and is only available if the timezone field is UTC.
+
 Usage (cli):
 
     $ dig example.com | jc --dig
@@ -22,7 +26,7 @@ Examples:
     $ dig cnn.com www.cnn.com @205.251.194.64 | jc --dig -p
     [
       {
-        "id": 34128,
+        "id": 52172,
         "opcode": "QUERY",
         "status": "NOERROR",
         "flags": [
@@ -44,38 +48,40 @@ Examples:
             "name": "cnn.com.",
             "class": "IN",
             "type": "A",
-            "ttl": 60,
+            "ttl": 27,
             "data": "151.101.65.67"
           },
           {
             "name": "cnn.com.",
             "class": "IN",
             "type": "A",
-            "ttl": 60,
-            "data": "151.101.193.67"
+            "ttl": 27,
+            "data": "151.101.129.67"
           },
           {
             "name": "cnn.com.",
             "class": "IN",
             "type": "A",
-            "ttl": 60,
+            "ttl": 27,
             "data": "151.101.1.67"
           },
           {
             "name": "cnn.com.",
             "class": "IN",
             "type": "A",
-            "ttl": 60,
-            "data": "151.101.129.67"
+            "ttl": 27,
+            "data": "151.101.193.67"
           }
         ],
-        "query_time": 37,
+        "query_time": 38,
         "server": "2600",
-        "when": "Tue Nov 12 07:14:42 PST 2019",
-        "rcvd": 100
+        "when": "Tue Mar 30 20:07:59 PDT 2021",
+        "rcvd": 100,
+        "when_epoch": 1617160079,
+        "when_epoch_utc": null
       },
       {
-        "id": 15273,
+        "id": 36292,
         "opcode": "QUERY",
         "status": "NOERROR",
         "flags": [
@@ -131,10 +137,12 @@ Examples:
             "data": "ns-576.awsdns-08.net."
           }
         ],
-        "query_time": 23,
+        "query_time": 27,
         "server": "205.251.194.64#53(205.251.194.64)",
-        "when": "Tue Nov 12 07:14:42 PST 2019",
-        "rcvd": 212
+        "when": "Tue Mar 30 20:07:59 PDT 2021",
+        "rcvd": 212,
+        "when_epoch": 1617160079,
+        "when_epoch_utc": null
       }
     ]
 
@@ -260,7 +268,7 @@ Examples:
     $ dig -x 1.1.1.1 | jc --dig -p
     [
       {
-        "id": 34898,
+        "id": 22191,
         "opcode": "QUERY",
         "status": "NOERROR",
         "flags": [
@@ -282,14 +290,16 @@ Examples:
             "name": "1.1.1.1.in-addr.arpa.",
             "class": "IN",
             "type": "PTR",
-            "ttl": 952,
+            "ttl": 1800,
             "data": "one.one.one.one."
           }
         ],
-        "query_time": 103,
+        "query_time": 44,
         "server": "2600",
-        "when": "Tue Nov 12 07:15:33 PST 2019",
-        "rcvd": 78
+        "when": "Tue Mar 30 20:10:34 PDT 2021",
+        "rcvd": 78,
+        "when_epoch": 1617160234,
+        "when_epoch_utc": null
       }
     ]
 
@@ -333,8 +343,8 @@ import jc.utils
 
 
 class info():
-    version = '1.5'
-    description = 'dig command parser'
+    version = '1.6'
+    description = '`dig` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
 
@@ -405,6 +415,8 @@ def process(proc_data):
             "query_time":     integer,   # in msec
             "server":         string,
             "when":           string,
+            "when_epoch":     integer,   # naive timestamp if when field is parsable, else null
+            "when_epoch_utc": integer,   # timezone aware timestamp availabe for UTC, else null
             "rcvd":           integer
             "size":           string
           }
@@ -452,6 +464,11 @@ def process(proc_data):
             except (ValueError):
                 entry['query_time'] = None
 
+        if 'when' in entry:
+            ts = jc.utils.timestamp(entry['when'])
+            entry['when_epoch'] = ts.naive
+            entry['when_epoch_utc'] = ts.utc
+
     return proc_data
 
 
