@@ -112,7 +112,7 @@ import jc.utils
 
 class info():
     version = '1.1'
-    description = 'dmidecode command parser'
+    description = '`dmidecode` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     # details = 'enter any other details here'
