@@ -83,7 +83,7 @@ import jc.parsers.universal
 
 class info():
     version = '1.2'
-    description = 'du command parser'
+    description = '`du` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     # details = 'enter any other details here'
