@@ -76,7 +76,7 @@ import jc.utils
 
 class info():
     version = '1.3'
-    description = 'fstab file parser'
+    description = '`/etc/fstab` file parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
 
