@@ -66,7 +66,7 @@ import jc.utils
 
 class info():
     version = '1.1'
-    description = '/etc/gshadow file parser'
+    description = '`/etc/gshadow` file parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     # details = 'enter any other details here'
