@@ -80,7 +80,7 @@ import jc.utils
 
 class info():
     version = '1.1'
-    description = 'id command parser'
+    description = '`id` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     # details = 'enter any other details here'
