@@ -107,7 +107,7 @@ import jc.parsers.universal
 
 class info():
     version = '1.2'
-    description = 'lsof command parser'
+    description = '`lsof` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
 
