@@ -193,7 +193,7 @@ import jc.parsers.universal
 
 class info():
     version = '1.3'
-    description = 'ntpq -p command parser'
+    description = '`ntpq -p` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
 
