@@ -84,7 +84,7 @@ import jc.utils
 
 class info():
     version = '1.1'
-    description = '/etc/passwd file parser'
+    description = '`/etc/passwd` file parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     # details = 'enter any other details here'
