@@ -90,7 +90,7 @@ import jc.utils
 
 class info():
     version = '1.1'
-    description = '/etc/shadow file parser'
+    description = '`/etc/shadow` file parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     # details = 'enter any other details here'
