@@ -50,7 +50,7 @@ import jc.utils
 
 class info():
     version = '1.0'
-    description = 'sysctl command parser'
+    description = '`sysctl` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     # details = 'enter any other details here'
