@@ -44,7 +44,7 @@ import jc.utils
 
 class info():
     version = '1.3'
-    description = 'systemctl list-sockets command parser'
+    description = '`systemctl list-sockets` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
 
