@@ -1,5 +1,7 @@
 """jc - JSON CLI output utility `timedatectl` command output parser
 
+The `epoch_utc` calculated timestamp field is timezone-aware and is only available if the universal_time field is available.
+
 Usage (cli):
 
     $ timedatectl | jc --timedatectl
@@ -28,7 +30,8 @@ Examples:
       "ntp_enabled": true,
       "ntp_synchronized": true,
       "rtc_in_local_tz": false,
-      "dst_active": true
+      "dst_active": true,
+      "epoch_utc": 1583888001
     }
 
     $ timedatectl | jc --timedatectl -p -r
@@ -47,8 +50,8 @@ import jc.utils
 
 
 class info():
-    version = '1.1'
-    description = 'timedatectl status command parser'
+    version = '1.2'
+    description = '`timedatectl status` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     # details = 'enter any other details here'
@@ -76,6 +79,7 @@ def process(proc_data):
         {
           "local_time":                        string,
           "universal_time":                    string,
+          "epoch_utc":                         integer,     # timezone-aware timestamp
           "rtc_time":                          string,
           "time_zone":                         string,
           "ntp_enabled":                       boolean,
@@ -96,6 +100,10 @@ def process(proc_data):
             except (ValueError):
                 proc_data[key] = None
 
+    if 'universal_time' in proc_data:
+        ts = jc.utils.timestamp(proc_data['universal_time'])
+        proc_data['epoch_utc'] = ts.utc
+
     return proc_data
 
 
