@@ -93,7 +93,7 @@ import jc.utils
 
 class info():
     version = '1.3'
-    description = 'w command parser'
+    description = '`w` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
 
